@@ -59,7 +59,7 @@ class SqlalchemyDataLayer(BaseDataLayer):
 
         return obj
 
-    def get_object(self, view_kwargs):
+    def get_object(self, view_kwargs, qs=None):
         """Retrieve an object through sqlalchemy
 
         :params dict view_kwargs: kwargs from the resource view
@@ -67,7 +67,24 @@ class SqlalchemyDataLayer(BaseDataLayer):
         """
         self.before_get_object(view_kwargs)
 
-        obj = self.retrieve_object(view_kwargs)
+        id_field = getattr(self, 'id_field', inspect(self.model).primary_key[0].key)
+        try:
+            filter_field = getattr(self.model, id_field)
+        except Exception:
+            raise Exception("{} has no attribute {}".format(self.model.__name__, id_field))
+
+        url_field = getattr(self, 'url_field', 'id')
+        filter_value = view_kwargs[url_field]
+
+        query = self.retrieve_object_query(view_kwargs, filter_field, filter_value)
+
+        if qs is not None:
+            query = self.eagerload_includes(query, qs)
+
+        try:
+            obj = query.one()
+        except NoResultFound:
+            obj = None
 
         self.after_get_object(obj, view_kwargs)
 
@@ -498,26 +515,15 @@ class SqlalchemyDataLayer(BaseDataLayer):
 
         return query
 
-    def retrieve_object(self, view_kwargs):
-        """Construct the base query to retrieve wanted object
+    def retrieve_object_query(self, view_kwargs, filter_field, filter_value):
+        """Build query to retrieve object
 
         :param dict view_kwargs: kwargs from the resource view
+        :params sqlalchemy_field filter_field: the field to filter on
+        :params filter_value: the value to filter with
+        :return sqlalchemy query: a query from sqlalchemy
         """
-        id_field = getattr(self, 'id_field', inspect(self.model).primary_key[0].key)
-        try:
-            filter_field = getattr(self.model, id_field)
-        except Exception:
-            raise Exception("{} has no attribute {}".format(self.model.__name__, id_field))
-
-        url_field = getattr(self, 'url_field', 'id')
-        filter_value = view_kwargs[url_field]
-
-        try:
-            obj = self.session.query(self.model).filter(filter_field == filter_value).one()
-        except NoResultFound:
-            obj = None
-
-        return obj
+        return self.session.query(self.model).filter(filter_field == filter_value)
 
     def query(self, view_kwargs):
         """Construct the base query to retrieve wanted data
